#!/bin/sh
# Copyright IBM Corp. 2000-2001

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Wizard Update Installer Application Launcher
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

MotifLAF=com.sun.java.swing.plaf.motif.MotifLookAndFeel

success_rc=0
fail_rc=$?

LaunchTitle=$0

runInstaller=
launchInstaller=
useLocalJDK=
prepareJDK=
useJavaHome=
checkSetup=
callSetup=
checkClientSetup=
callClientSetup=
failSetup=
testJDK=
copyJDK=
failedCopyJDK=
okCopyJDK=
skipCopyJDK=
runJavaHome=
skip=

currentDir=`dirname $0`

PREREQ_DISABLE_INST=
PREREQ_DISABLE_UNINST=
FOR_EFIX=
RUN_JAVA_HOME=

#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
whoami | grep "root"

if [ $? -ne 0 ]; then
	echo "must logged in as root to apply the fixpack, exiting"
	exit 1
fi

echo Copy properties files
echo "Checking properties"
if [ -f "/home/thinkcontrol/properties/version/THINKCONTROL.product" ]; then
	echo "Properties dir exists"
	
else
	echo creating directories for properties
	mkdir -p /home/thinkcontrol/properties
	mkdir -p /home/thinkcontrol/properties/version
	mkdir -p /home/thinkcontrol/properties/version/backup
	mkdir -p /home/thinkcontrol/properties/version/dtd
	mkdir -p /home/thinkcontrol/properties/version/history
	mkdir -p /home/thinkcontrol/properties/version/log
	mkdir -p /home/thinkcontrol/properties/version/log/wizard

	echo moving properties files over
	mv ../properties/version/THINKCONTROL.product /home/thinkcontrol/properties/version/THINKCONTROL.product
	mv ../properties/version/platform.tivoli  /home/thinkcontrol/properties/version/platform.tivoli
	mv ../properties/version/thinkcontrol.component /home/thinkcontrol/properties/version/thinkcontrol.component
	mv ../properties/version/aix.component /home/thinkcontrol/properties/version/aix.component
	mv ../properties/version/dtd/*  /home/thinkcontrol/properties/version/dtd/
fi


echo Start of [ "$LaunchTitle" ]
echo

echo Verifying installer jar:
echo   [ installer.jar ]
echo
if [ -f "$currentDir"/installer.jar ] 
   then        
	while [ "$1" ]
	   do 	   		
	      if [ "$1" = "-dpInstall" ]
	 	 then 
		      PREREQ_DISABLE_INST="-W EfixInstallPrereqError.prereqOverride=yes"
	      elif [ "$1" = "-dpUninstall" ] 
		 then
		      PREREQ_DISABLE_UNINST="-W EfixUninstallPrereqError.prereqOverride=yes"
	      elif [ "$1" = "-efixOnly" ] 
	         then
	              FOR_EFIX="-W UpdateActionSelect.disablePTFOptions=yes"
	      elif [ "$1" = "-skipJDKCopy" ] 
	         then
	              RUN_JAVA_HOME="yes"
	      elif [ "$1" = "-usage" ] 
	         then
	              echo
	              echo Usage: updateWizard [ -efixOnly ] [ -dpInstall ] [ -dpUninstall ] [ -skipJDKCopy ] [ -usage ]
		      echo
		      echo   efixOnly    - Run the installer in EFix Processing mode only. 
		      echo   dpInstall   - Disable install prerequisite error locking.	
		      echo   dpUninstall - Disable uninstall prerequisite error locking.
		      echo   skipJDKCopy - Run the installer directly from JAVA_HOME
		      echo   usage       - Display syntax help. 
		      echo       	
		      exit $fail_rc            	           	  		  
		 else 
		      echo Usage error: [ "$1" is an unrecognized argument ]	          	          	          
		      exit $fail_rc
	      fi	     	       	     
	      
	      shift	      
	done

        JAVA_TMP="$currentDir"/java_tmp
        JAVA_EXE="$JAVA_TMP"/bin/java
        if [ -f "$JAVA_EXE" ]
           then 
               useLocalJDK=1
           else
               JRE_EXE="$currentDir"/java_tmp/jre/bin/java
               if [ -f "$JRE_EXE" ]
                 then
                    JAVA_TMP="$currentDir"/java_tmp/jre
                    useLocalJDK=1
                 else prepareJDK=1
               fi 
        fi
   else
        echo The installer jar file does not exist.  
        echo Exiting.
        echo
        exit $fail_rc
fi       
 
           
if [ "$useLocalJDK" ]
   then
        JAVA_HOME="$JAVA_TMP"
        if [ "$DEBUG_UPDATE" ] 
           then
        	echo Using the local copy of the JDK, made previously, for processing:
        	echo   JAVA_HOME: [ "$JAVA_HOME" ]
		echo 
	fi
        
        launchInstaller=1 	 
fi

if [ "$prepareJDK" ]
   then 
        if [ "$JAVA_HOME" ] 
           then 
                useJavaHome=1
           else
                checkClientSetup=1
        fi
fi


if [ "$checkClientSetup" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME is not set.
        	echo Attempting to locate setupClient.sh
        	echo
        fi
        
        if [ -f "$currentDir"/../bin/setupClient.sh ]
           then
                callClientSetup=1
                JAVA_TMP="$currentDir"/java_tmp/jre
                checkSetup=
           else
                checkSetup=1
        fi
fi

if [ "$checkSetup" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME is not set.
        	echo Attempting to locate setupCmdLine.sh
        	echo
        fi
        
        if [ -f "$currentDir"/../bin/setupCmdLine.sh ]
           then
                callSetup=1
           else
                failSetup=1
        fi
fi

if [ "$useJavaHome" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME was set
        	echo     JAVA_HOME: [ "$JAVA_HOME" ]
        	echo
        fi
        
        testJDK=1
fi

if [ "$failSetup" ]
   then        
        echo JAVA_HOME must be set before launching the update wizard
	echo     JAVA_HOME was not set
	echo     Set JAVA_HOME manually with the install_root/bin/setupCmdLine.sh or setupClient.sh script. 
        echo
	echo setupCmdLine.sh or setupClient.sh is usually located beneath your
	echo WebSphere installation, in the 'bin'
	echo directory. 
	echo
	echo Exiting.	
	echo
	exit $fail_rc 
fi

if [ "$callSetup" ]
   then
        . $currentDir/../bin/setupCmdLine.sh
        testJDK=1
fi

if [ "$callClientSetup" ]
   then
        . $currentDir/../bin/setupClient.sh
        testJDK=1
fi

if [ "$testJDK" ]
   then
        if [ -f "$JAVA_HOME"/bin/java ]
           then
                if [ "$RUN_JAVA_HOME" ]
                   then
                        runJavaHome=1
                   else
                        copyJDK=1
                fi           
           else
                echo The JDK was not found within the set JAVA_HOME
        	echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
        	echo
        	echo Exiting.
        	echo
        	exit $fail_rc
        fi           
fi        

PLATFORM=`uname`
export PLATFORM
                 
if [ "$copyJDK" ]
   then
   	if [ "$FOR_EFIX" ]
   	   then
   	       skipCopyJDK=1   	      	   
   	   else   	          
	        echo Making local copy of the JDK, which is required
		echo for PTF processing:
		echo   JAVA_HOME: [ "$JAVA_HOME" ]
		echo   JAVA_TMP:  [ "$JAVA_TMP" ]
		echo 
		
		if [ -d "$JAVA_TMP" ]
		   then 
		         `cp -r "$JAVA_HOME"/* "$JAVA_TMP"`
		         okCopyJDK=1
		   else
		         `mkdir -p "$JAVA_TMP"`
		         if [ -d "$JAVA_TMP" ]
		            then
                                 if [ "$PLATFORM" = "AIX" ]; then
                                    `slibclean`
                                 fi;
		                 `cp -r "$JAVA_HOME"/* "$JAVA_TMP"`
		         
		                 if [ -f "$JAVA_TMP"/bin/java ] 
		                    then
		                          okCopyJDK=1	                 	  
		            	    else 
		                 	  failedCopyJDK=1
		                 fi
		           
		            else
		                  failedCopyJDK=1 
		         fi	         
		fi
	fi
fi	                
if [ "$runJavaHome" ]
   then
       echo No local copy of the JDK will be created.
       echo The installer will run directly from JAVA_HOME.       
       launchInstaller=1
fi
      
if [ "$skipCopyJDK" ]
   then
       echo EFix processing was selected.
       echo No local copy of the JDK will be created.  
       echo PTF processing is disabled. 
       launchInstaller=1
fi       
        

if [ "$failedCopyJDK" ]
   then
        echo The JDK could not be copied into the current directory.
	echo JAVA_HOME: [ "$JAVA_HOME" ]
	echo JAVA_TMP:  [ "$JAVA_TMP" ]
	echo
	echo Exiting.
	echo
	exit $fail_rc
fi

if [ "$okCopyJDK" ]
   then 
        echo The JDK was successfully copied
        echo 
        
        JAVA_HOME="$JAVA_TMP"
        launchInstaller=1
fi

	                   
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in 
        Linux)
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/i386:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux:${SHLIB_PATH}
                export SHLIB_PATH
                
                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/libUnixFileUtils.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/libUnixFileUtils.sl
                fi                 
                ;;
        AIX)    
                LIBPATH=${currentDir}/lib/linux:${LIBPATH}
                export LIBPATH
                ;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac
	
	                   
#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

if [ "$launchInstaller" ] 
  then                               
       if [ "$FOR_EFIX" ]
          then
               if [ "$PREREQ_DISABLE_INST" ]
                  then
                       if [ "$PREREQ_DISABLE_UNINST" ]
                          then        
                               runInstaller=1        
                               skip=1
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
    	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"`    	                    
  	               fi
  	        fi 
  	        
  	        if [ "$PREREQ_DISABLE_UNINST" ]
                  then
                       if [ "$PREREQ_DISABLE_INST" ]
                          then   
			       if [ "$skip" ]                          
                                  then 
                                       echo
                                  else
                               	       runInstaller=1             
                               	       "$JAVA_HOME"/bin/java \
                               	       -Xmx256m \
 	                               -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       	       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	                       	       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                       fi
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
    	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_UNINST"`    	                    
  	               fi
  	        fi 
  	        
  	        if [ "$runInstaller" ]
  	           then
  	           	echo
  	           else  	                
  	                runInstaller=1    
  	                
                	"$JAVA_HOME"/bin/java \
                	-Xmx256m \
 	                -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	        	-DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	        	run `echo "$FOR_EFIX"`
  	        fi    
  	   else  	   
  	   	if [ "$PREREQ_DISABLE_INST" ]
                   then
                        if [ "$PREREQ_DISABLE_UNINST" ]
                           then        
                               skip=1
                               runInstaller=1        
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	                       run `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
    	                       run `echo "$PREREQ_DISABLE_INST"`    	                    
  	                fi
  	        fi 
  	        
  	        if [ "$PREREQ_DISABLE_UNINST" ]
                   then
                       if [ "$PREREQ_DISABLE_INST" ]
                          then   
                               if [ "$skip" ]
                                  then
                                        echo
                                  else
                               		runInstaller=1             
                               		"$JAVA_HOME"/bin/java \
                               		-Xmx256m \
 	                                -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       		-DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	                       		run `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                       fi
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx256m \
 	                       -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	                       -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
    	                       run `echo "$PREREQ_DISABLE_UNINST"`    	                    
  	               fi
  	        fi   	          	       	   
        fi
  	
  	if [ "$runInstaller" ] 
  	   then echo 
  	   else  	     
  	     "$JAVA_HOME"/bin/java \
  	     -Xmx256m \
 	     -cp "$currentDir"/lib/wcsdepcheck.jar:"$currentDir"/lib/WCextensions.jar:"$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar:"$currentDir"/lib/jtopen.jar \
  	     -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=true -DprodHelper="com.ibm.commerce.install.update.WCProductDetectHelper" -Dcom.ibm.websphere.update.debug="true" -Dcom.ibm.websphere.update.ptf.debug="true" \
  	     run
  	fi
  	                    	    
fi

echo End of [ "$LaunchTitle" ]
echo

echo "update-I-signature"
#decide it's TIO or TPM
sed -e 's/  */ /g' /home/thinkcontrol/config/ui.xml > /tmp/ui$$
grep -e "<!-- <configuration id='think-provision'/> -->" /tmp/ui$$ > /tmp/temp$$

if [ $? -ne 0 ]; then
	echo "product-I-detected: Tivoli Provisioning Manager"
	if [ -f /home/thinkcontrol/config/TIOSignature.xml ]; then
		rm -f /home/thinkcontrol/config/TIOSignature.xml
	fi
else
	echo "product-I-detected: Tivoli Intelligent Orchestrator" 
	if [ -f /home/thinkcontrol/config/TPMSignature.xml ]; then
		rm -f /home/thinkcontrol/config/TPMSignature.xml
	fi
fi
rm -f /tmp/temp$$
rm -f /tmp/ui$$ 

echo "update-I-user-factory"
echo "check the version"
#check the format
temp=/tmp/temp$$
version_file=/tmp/version$$
if [ ! `grep "build.number=U" "/home/thinkcontrol/config/build-version.properties" ` ]; then
	echo this is not the fixpack version
else 	
	grep 'build.number' /home/thinkcontrol/config/build-version.properties | sed -e 's/build.number=U//' > $temp
	cat $temp | cut -d _ -f1 > $version_file
	version=`cat $version_file`
	rm -f $version_file
	if [ $version -gt 788 ]; then
		current_dir=`dirname $0`
		[ "$current_dir" = "." ] && current_dir=`pwd`

		#need unzip utility
		which unzip > $temp
		if [ `grep "not found" $temp` ]; then
			echo "no unzip utility installed, user-factory.xml is not updated, please update it manually and redeploy the tcje.ear file"
			rm -f $temp
			exit 1
		fi

		#get the latest undo.jar in backup dir
		ls -t /home/thinkcontrol/properties/version/backup | grep jar | head -1 > $temp
		jar_name=`cat $temp`

		cd $current_dir
		#get the old user-factory.xml
		unzip -o  /home/thinkcontrol/properties/version/backup/$jar_name /config/user-factory.xml -d .
		mv -f $current_dir/config/user-factory.xml /tmp/user-factory.xml

		# process the old file 
		old_file=/tmp/user-factory.xml
		TC__LDAPHOST=`grep '<server>' $old_file | sed -e 's^\(.*\)<server>\(.*\)</server>\(.*\)^\2^'` 
		TC__LDAPDOMAIN=`grep '<root>' $old_file | sed -e 's^\(.*\)<root>\(.*\)</root>\(.*\)^\2^'` 
		TC__LDAPPRINCIPAL=`grep '<principal>' $old_file | sed -e 's^\(.*\)<principal>\(.*\)</principal>\(.*\)^\2^'`
		TC__LDAPPRINCIPWDEEE=`grep '<credentials>' $old_file | sed -e 's^\(.*\)<credentials>\(.*\)</credentials>\(.*\)^\2^'`
		TC__LDAPUSER=`grep '<internal-user>' $old_file | sed -e 's^\(.*\)<internal-user>\(.*\)</internal-user>\(.*\)^\2^'`
		TC__LDAPPWDEEE=`grep '<internal-password>' $old_file | sed -e 's^\(.*\)<internal-password>\(.*\)</internal-password>\(.*\)^\2^'`
 
		# replace the variables in new file with the old values 
		new_file=/home/thinkcontrol/config/user-factory.xml
		if [ ! `grep 'TC__' $new_file` ]; then 
			echo "this configuaration file does not need to be replaced"
		else
			grep 'TC__' $new_file |sed -e 's/.*\(TC__[A-Z]*\).*/\1/g' |\
			while read TC_VAR
			do
				eval TC_VAL=\$$TC_VAR
				echo "/$TC_VAR/
				s/$TC_VAR/$TC_VAL/
				wq" | ex $new_file
			done

			#hardcode for bug 6570
			sed -e 's^<principal>root</principal>^<principal>tioldap</principal>^' $new_file > $temp
			mv -f $temp $new_file
			sed -e 's^<credentials>.*</credentials>^<credentials>8zLQrjH640c=</credentials>^' $new_file > $temp
			mv -f $temp $new_file
  		fi
	fi
fi

echo "TC-I-OWNERSHIP: changing file ownership to tioadmin"
group_id=`id tioadmin|cut -f2 -d" "|sed -e's/.*(\(.*\)).*/\1/'`
chown -R tioadmin:$group_id /home/thinkcontrol
if [ $? -ne 0 ]; then 
	echo " TC-E-OWNERSHIP: NEED TO CHANGE FILE OWNERSHIP IN HOME DIRECTORY"
fi

echo redeploy EAR file
su - tioadmin -c '$WAS_HOME/bin/startServer.sh server1'
su - tioadmin -c '$WAS_HOME/bin/wsadmin.sh -f $HOME/tools/was_deploy.jacl $HOME/lib/tcje.ear -user wasadmin -password wasadmin'
if [ $? -ne 0 ]; then
	echo "TCEAR-E-DEPLOY: error when deploying  tcje.ear"
fi
su - tioadmin -c '$WAS_HOME/bin/stopServer.sh server1 -user wasadmin -password wasadmin'

exit $success_rc
