/*
 * @(#)src/tools/pfm/java_md.c, tool, ax131, 20030523 1.12.1.2
 * ===========================================================================
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 *
 * IBM Java(tm)2 SDK, Standard Edition, v 1.3.1
 * (C) Copyright IBM Corp. 1998, 2001. All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ===========================================================================
 */

/*
 *
 * ===========================================================================
 *
 * Copyright 1998-2000 Sun Microsystems, Inc. All Rights Reserved.
 *
 * ===========================================================================
 * Change activity:
 *
 * Reason  Date   Origin  Description
 * ------  ----   ------  ----------------------------------------------------
 * 056789  210103 websterm Sidecar launcher
 *
 * ===========================================================================
 */

/*
 * @(#)java_md.c        1.11 99/04/22
 *
 */

#include "java.h"
#include <dlfcn.h>
#include <string.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
/*ibm@7468
#include <libgen.h>
    libgen.h removed from Linux as it redefines basename to be
    __xpg_basename which gives incorrect results.  The prototypes for
    dirname and basename are instead defined here */
extern char *basename(const char *filename);                /*ibm@7468*/
extern char *dirname(const char *path);                     /*ibm@7468*/
#include <sys/stat.h>                                       /*ibm@106*/
#include <errno.h>                                          /*ibm@7468*/

#define TRUE 1                                              /*ibm@7468*/
#define FALSE 0                                             /*ibm@7468*/
#if defined(IBM_BUILD_TYPE_dev)                             /*ibm@106*/
#define JVM_DLL  "libjvm_d.so"
#elif defined(IBM_BUILD_TYPE_col)                           /*ibm@106*/
#define JVM_DLL  "libjvm_g.so"
#else                                                       /*ibm@106*/
#define JVM_DLL  "libjvm.so"
#endif                                                      /*ibm@106*/

static char JavaHomeDir[MAXPATHLEN];                        /*ibm@7468*/

/* start ibm@1369
 * Expand command line arguments.
 */
void
ExpandCommandLineArgs() {
    /* DO NOTHING */
}
/* end   ibm@1369 */

/**************************************************************************
 * name         - ibmFindJVMDLL
 * description  - 
 *      Find a JVM DLL.
 *      ibm@250  fixed strtok problem causing -X option to core.
 *      ibm@7468 rewritten to use GatApplicationHome
 *
 * parameters   - jvmtype (the name of the jvm type : "classic" or "hotspot")
 * returns      - path to JVM DLL
 **************************************************************************/
static char *                                                /*ibm@106*/
ibmFindJVMDLL(char * jvmtype) {
    struct stat s;
    char home[MAXPATHLEN], dll[MAXPATHLEN];
    char *p;

    /*
     * If we haven't been given a type, default to "classic".
     */
    if (jvmtype == NULL) {
        jvmtype = "classic\0";
    }

    strcpy(dll, "/jre/bin/");
    strcat(dll, jvmtype);
    strcat(dll, "/" JVM_DLL);

    if (GetApplicationHome(home, MAXPATHLEN) == JNI_TRUE) {

        p = home + strlen(home); /* pointer to end of home */

        strcpy(p, dll+4);  /* drop the "/jre" bit for the first test */

        if (stat(home, &s) != 0) {

            /*
             * Not found so check for JVM_DLL in a /jre subdirectory
             */
            strcpy(p, dll);
            if (stat(home, &s) != 0) {
                return(char *)NULL;
            }
        }

        return strdup(home);

    }

    return(char *)NULL;

}


/**************************************************************************
 * name        - LoadJavaVM (ibm@149)
 * description -
 *      Load JVM and initialize the invocation functions.
 *      Re-written for AIX to dynamically open the JVM dll and find the
 *      the entry points rather than having to be linked with the library
 *      This matches the Win32 function rather than Solaris.
 *      Currently the jvmtype (classic or hotspot) is ignored - as on
 *      Solaris.
 * 
 * parameters  - jvmtype (name of jvm type, currently "classic")
 *               ifn (vector of functions which receives the function
 *                    pointers found in the jvm DLL)
 * returns     - JNI_TRUE if successful
 **************************************************************************/
jboolean
LoadJavaVM(char *jvmtype, InvocationFunctions *ifn) {
    /* Implementation rewritten                                   *//*ibm@149*/
    char *jvmpath = (char *)0;                                     /*ibm@56789*/
    void *hJvm;

    /* 
     * Try to load the J9 JVM if in debug mode. If not, or J9 is not present,
     * load the default JVM.
     */
    /*ibm@56789*/
    if (JNI_TRUE == ifn->debug) {
        jvmpath = ibmFindJVMDLL("j9vm");
    }
    if ((char *)0 == jvmpath) {
        jvmpath = ibmFindJVMDLL(jvmtype);
    }
    if ((char *)0 == jvmpath) {                           /*ibm@7468 ibm@56789*/
        fprintf(stderr, "Can't find "JVM_DLL" \n");
        return JNI_FALSE;
    } else {
        hJvm = dlopen(jvmpath,RTLD_LAZY);
        if (hJvm==NULL) {
            fprintf(stderr, "LoadJavaVM: unable to open DLL (%s)\n", jvmpath);
            fprintf(stderr, "%s\n", dlerror());
            free(jvmpath);
            return JNI_FALSE;
        }

        ifn->CreateJavaVM = (jint (JNICALL *)(JavaVM **pvm, void **penv, void *args))
                            dlsym(hJvm,"JNI_CreateJavaVM");
        if (ifn->CreateJavaVM==NULL) {
            fprintf(stderr, "LoadJavaVM: unable to find JVM function (JNI_CreateJavaVM in %s)\n", jvmpath);
            fprintf(stderr, "%s\n", dlerror());
            free(jvmpath);
            return JNI_FALSE;
        }
        ifn->GetDefaultJavaVMInitArgs = (jint (JNICALL *)(void *args))
                                        dlsym(hJvm,"JNI_GetDefaultJavaVMInitArgs");
        if (ifn->GetDefaultJavaVMInitArgs==NULL) {
            fprintf(stderr, "LoadJavaVM: unable to find JVM function (JNI_GetDefaultJavaVMInitArgs in %s)\n", jvmpath);
            fprintf(stderr, "%s\n", dlerror());
            free(jvmpath);
            return JNI_FALSE;
        }
        free(jvmpath);
        return JNI_TRUE;
    }

}

/**************************************************************************
 * name        - GetXUsagePath
 * description -
 *      Get the path to the file that has the usage message for -X options.
 *
 * parameters  - buf (the receiving buffer for the path)
 *               bufsize (the size of buf)
 * returns     - 
 **************************************************************************/
void
GetXUsagePath(char *buf, jint bufsize) {
/*
 * Assume LD_LIBRARY_PATH is set; Xusage.txt in same place as libjvm.
 */
    char *jvmpath;                                                  /*ibm@106*/

    if ((jvmpath = ibmFindJVMDLL((char *)0)) == (char *)0) {         /*ibm@106*//*ibm@7468*/
        fprintf(stderr, "Can't find the "JVM_DLL" \n");             /*ibm@113*/
    }                                                               /*ibm@106*/
    else {                                                          /*ibm@106*/
        strncpy(buf, jvmpath, bufsize-1);                           /*ibm@106*/
        free(jvmpath);                                              /*ibm@106*/
    }                                                               /*ibm@106*/

    buf[bufsize-1] = '\0';
    *(strrchr(buf, '/')) = '\0';
    strcat(buf, "/Xusage.txt");
}


/**************************************************************************
 * name        - ResolveSymbol (ibm@7468)
 * description -
 *      Given a buffer containing a path resolve any symbols in the last 
 *      component of the path. If the symbol resolves to a relative path
 *      add it to the original. Otherwise replace it.
 *
 * parameters  - pUsed (ptr to a buffer holding the current path)
 * returns     -
 *************************************************************************/
void
ResolveSymbol(char *pUsed) {
    char buffer[MAXPATHLEN];
    char *p = pUsed;
    int len;

    if ((len = readlink(pUsed, buffer, MAXPATHLEN)) >= 0) {
        buffer[len] = 0;

        /* Did it resolve to a relative symbol ? */
        if (buffer[0] != '/') {                             /*ibm@8327*/
            p= strrchr(pUsed, '/')+1;
        }

        strcpy(p, buffer);
    } else if (len == MAXPATHLEN) {
        fprintf(stderr, "BuildPath: Symbolic link too long > %d\n", MAXPATHLEN);
        fprintf(stderr, "BuildPath: using %s\n", pUsed);
    } else if (errno != EINVAL) {
        fprintf(stderr, "BuildPath: %s\n", strerror(errno));
        fprintf(stderr, "BuildPath: using %s\n", pUsed);
    }

}


/**************************************************************************
 * name        - DeDot (ibm@7468)
 * description -
 *      Given a path in pUsed remove any trailing "."s, resolve any
 *      trailing ".."s resolving symbolic links before removal.
 *
 * parameters  - pUsed (ptr to a buffer holding the path)
 * returns     -
 *************************************************************************/
void
DeDot(char *pUsed) {
    char *p;

    /*
     * Remove any trailing "."s
     * stopping when we get to a non-dot item or
     * we have consumed the whole path
     */
    while (strcmp(basename(pUsed),".") == 0 && strcmp(pUsed,".") != 0) {
        p = dirname(pUsed);
        if (pUsed != p) {
            strcpy(pUsed, p);
        }
    }

    if (strcmp(basename(pUsed),"..") == 0) {
        p = dirname(pUsed);
        if (pUsed != p) {
            strcpy(pUsed, p);
        }

        DeDot(pUsed);
        ResolveSymbol(pUsed);
        p = dirname(pUsed);
        if (pUsed != p) {
            strcpy(pUsed, p);
        }
    }

    /* ibm@4885 If all that we have left is a single "."
     * replace it with the current working directory
     */
    if (strcmp(pUsed, ".") == 0) {
        getcwd(pUsed, MAXPATHLEN);
    }

}

/**************************************************************************
 * name        - BuildHomeDir (ibm@7468)
 * description -
 *      From the supplied executable name determine the true home directory.
 *      This function is called once to set up JavaHomeDir.
 *
 * parameters  - fname (The name of this executable, may be short or long)
 * returns     -
 *************************************************************************/
void
BuildHomeDir(char *fname) {
    char *path;
    char *p;
    int len;
    char dir[MAXPATHLEN];
    char *found = NULL;
    struct stat s;

    /*
     *  Is the exe name fully, or partially qualified?
     */
    if (strchr(fname, '/') != NULL && stat(fname, &s) == 0) {
        if (fname[0] == '/') {
            strcpy(dir, fname);
            found = dir;
        } else {
            getcwd(dir, MAXPATHLEN);

            path = dir;
            p = fname;
            while (p[0] == '.') {
                if (strstr(p, "../") == p) {
                    p = p+3;
                    path = dirname(path);
                } else {
                    p = p+2;
                }
            }
            strcat(path, "/");
            strcat(path, p);

            found = path;
        }
    } else {
        /*
         * If not found, assume it's a short name and search the path variable...
         */

        path = getenv("PATH");

        while (path != NULL) {
            /*
             *  Get the first element of the path
             */

            p = strchr(path, ':');

            if (p != NULL) {

                /*
                 * There is more than one
                 */
                len = p - path;
                strncpy(dir, path, len);
                dir[len] = 0;
                path = p+1;
            } else {

                /*
                 * Last path element...
                 */
                strcpy(dir, path);
                path = NULL;
            }

            /*
             * Add the exe name to the path element and check it points to a file.
             */
            strcat(dir, "/");
            strcat(dir, fname);
            if (stat(dir, &s) == 0) {
                /*
                 * We have found a match!
                 */
                found = dir;
                break;
            }

        }

    }

    /*
     * Did we find it?
     */
    if (found != NULL) {
        /*
         * Resolve symbolic link in name
         */
        ResolveSymbol(found);

        /*
         * Strip the exc's name off the end.
         */
        p = dirname(found);
        if (found != p) {
            strcpy(found, p);
        }

        ResolveSymbol(found);

        DeDot(found);

        if (strcmp(basename(found), "exe") == 0) {
            p = dirname(found);
            if (found != p) {
                strcpy(found, p);
            }
        }

        /*
         * Remove the next component which should be /bin
         */
        p = dirname(found);
        if (found != p) {
            strcpy(found, p);
        }

        ResolveSymbol(found);

        DeDot(found);

        /*
         * If the next component is /jre remove it
         */
        if (strcmp(basename(found),"jre") == 0) {
            p = dirname(found);
            if (found != p) {
                strcpy(found, p);
            }

            ResolveSymbol(found);

            DeDot(found);
        }

        strcpy(JavaHomeDir, found);
    }

}

/**************************************************************************
 * name        - GetApplicationHome (ibm@7468)
 * description -
 *      Get the application home directory, which will have been calculated
 *      by BuildHomeDir.
 *
 * parameters  - buf     The receiving buffer for the path
 *               bufsize The size of the receiving buffer (not used)
 * returns     - JNI_TRUE
 **************************************************************************/
jboolean
GetApplicationHome(char *buf, jint bufsize) {
    strcpy(buf, JavaHomeDir);

    return JNI_TRUE;

}

/**************************************************************************
 * name        - setLibPath (ibm@7468)
 * description -
 *      Clean up the LD_LIBRARY_PATH environment variable, and add our bin
 *      directory to it.
 *
 * parameters  - 
 * returns     - 
 **************************************************************************/
void
setLibPath() {

    char newpath[MAXPATHLEN];
    char base[MAXPATHLEN];
    char *p;
    char *buffer = newpath;
    char *path = getenv("LD_LIBRARY_PATH");
    int len;

    /*
     * Add the jre/bin directory to the start of LD_LIBRARY_PATH
     */
    strcpy(newpath, "LD_LIBRARY_PATH=");
    strcat(newpath, JavaHomeDir);
    strcat(newpath, "/jre/bin:");

    strcat(newpath, JavaHomeDir);
    strcat(newpath, "/jre/bin/classic");

    /*
     * Now clean up LD_LIBRARY_PATH
     */
    while (path != NULL) {

        /* Get the first element of the path */

        p = strchr(path, ':');

        if (p == path) {
            /* Discard null path entry "::" */
            p++;
        } else {
            if (p != NULL) {
                len = p - path;
                p++;
            } else {
                len = strlen(path);
            }

            /* Discard trailing path separator */
            if (len > 0 && path[len-1] == '/') {
                len--;
            }
            if (strncmp(path, "/lib", 4) &&
                strncmp(path, "/usr/lib", 8) &&
                strncmp(path, "/usr/ccs/lib", 12) && len > 0) {
                strcat(newpath, ":");
                strncat(newpath, path, len);

            }
        }

        /* Move to the next path item */
        path = p;

    }

    putenv(strdup(newpath));
}

/**************************************************************************
 * name        - setEnvVars (ibm@7468)
 * description -
 *      Set the environment variables needed by Java.
 *
 * parameters  - 
 * returns     - 
 **************************************************************************/
void
setEnvVars() {

    char newpath[MAXPATHLEN];
    char *p;
    char *buffer = newpath;

    /* Now add our locale files to the beginning of XFILESEARCHPATH */

    strcpy(buffer, "XFILESEARCHPATH=");
    strcat(buffer, JavaHomeDir);
    strcat(buffer, "/jre/lib/locale/%L/%T/%N%S:");

    p = getenv("XFILESEARCHPATH");
    if (p != NULL) {
        strcat(buffer, p);
    }
    putenv(strdup(buffer));

}

/**************************************************************************
 * name        - setLibAndExec (ibm@7468) 
 * description -
 *      AIX and Linux dlopen have problems with LD_LIBRARY_PATH changes
 *      made in the same process that is calling dlopen. Both use the 
 *      value of LD_LIBRARY_PATH at process exec time. If JAVA has been 
 *      executed without LD_LIBRARY_PATH containing the 130 lib paths, 
 *      this function adds them, and re-execs JAVA to ensure that dlopen 
 *      sees the new LD_LIBRARY_PATH setting.
 *
 * parameters  - argc (The count of arguments passed to main)
 *               arcv (Array of parameters taken from the command line)
 * returns     - 
 **************************************************************************/
void
setLibAndExec(int argc, char *argv[]) {
    char libpath1[MAXPATHLEN];
    char libpath2[MAXPATHLEN];
    char buff[MAXPATHLEN];
    char *p, *path;
    int lib1 = FALSE, lib2 = FALSE;

    /*
     * Look through LD_LIBRARY_PATH for the 130 libraries.
     * Ensure the 130 libraries are before other potentially
     * conflicting libraries.
     */

    BuildHomeDir(argv[0]);
    p = getenv("LD_LIBRARY_PATH");
    strcpy(path = buff, p == NULL ? "" : p);
    sprintf(libpath1, "%s/jre/bin", JavaHomeDir);
    sprintf(libpath2, "%s/jre/bin/classic", JavaHomeDir);

    while (path != NULL) {
        if ((p = strchr(path, ':')) != NULL) {
            *p++='\0';
        }
        if (!strcmp(path, libpath1)) {
            lib1=TRUE;
        }
        else if (!strcmp(path, libpath2)) {
            lib2=TRUE;
        } else {
            break;
        }
        path = p;
    }

    if (!lib1 || !lib2) {
        setLibPath();
        execvp(argv[0], argv);
    }
    setEnvVars();
}
